/*
 * Copyright (c) 2020-2021 CNRS/LAAS
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef _ICUB_INTERNAL_H
#define _ICUB_INTERNAL_H

#include <pthread.h>
#include <stdbool.h>
#include <stdint.h>

#ifndef _PRIVATE
#define _PRIVATE __attribute__((visibility ("hidden")))
#endif

struct CAN_MSG;

struct icub_node {
	struct icub_dev *parent;
	uint8_t addr;		/* can address */
	int board_type;
	uint8_t bl_maj, bl_min;
	uint8_t ap_maj, ap_min, ap_build;
	uint8_t can_maj, can_min;
	bool reply_pending;
	bool fw_ok;
	pthread_mutex_t mutex;
	pthread_cond_t cond;
	/* should be a union of the different possible boards */
	struct strain2_data strain2;
};

struct icub_dev {
	int fd;
	struct icub_node nodes[ICUB_MAX_NODES];
	int (*send)(int, struct CAN_MSG *);
	int (*recv)(int, struct CAN_MSG *, int);
	void (*end)(int);
};

#endif	/* _ICUB_INTERNAL_H */
