/*
 * Copyright (c) 2020-2021 CNRS/LAAS
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef _Q15_H
#define _Q15_H

static __inline__ int16_t
int16(uint8_t msb, uint8_t lsb)
{
	return (msb << 8) + lsb;
}

/* https://en.wikipedia.org/wiki/Q_(number_format) */

static __inline__ float
q15_to_float(int16_t q)
{
	return (float)q / 32768.0f;
}

static __inline__ int16_t
float_to_q15(float f)
{
	return f * 32768.0f;
}

static __inline__ float
u16_to_float(uint8_t msb, uint8_t lsb)
{

	return q15_to_float(int16(msb, lsb) + 0x8000);
}

static __inline__ uint16_t
float_to_u16(float x)
{
	return (uint16_t)float_to_q15(x) - 0x8000;
}

#endif	/* _Q15_H */
